mAddEntry (DicomElement ( DicomTag ( 0x0002, 0x0000 ), "MfGroupLength",                               "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0002, 0x0002 ), "MfSopClass",                                  "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0002, 0x0003 ), "MfSopInstance",                               "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0002, 0x0010 ), "MfTransferSyntax",                            "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0000 ), "IdentifyingGroupLength",                      "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0001 ), "LengthToEnd",                                 "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0005 ), "CharacterSet",                                "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0008 ), "ImageType",                                   "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0012 ), "InstanceCreationDate",                        "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0013 ), "InstanceCreationTime",                        "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0014 ), "InstanceCreatorUid",                          "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0016 ), "SopClass",                                    "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0018 ), "SopInstance",                                 "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0020 ), "StudyDate",                                   "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0021 ), "SeriesDate",                                  "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0022 ), "AcquisitionDate",                             "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0023 ), "ContentDate",                                 "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x002A ), "AcquisitionDateTime",                         "DT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0030 ), "StudyTime",                                   "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0031 ), "SeriesTime",                                  "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0032 ), "AcquisitionTime",                             "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0033 ), "ContentTime",                                 "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0050 ), "AcessionNumber",                              "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0060 ), "Modality",                                    "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0064 ), "ConversionType",                              "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0070 ), "Manufacturer",                                "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0080 ), "InstitutionName",                             "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0081 ), "InstitutionAddress",                          "ST" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0090 ), "ReferringPhysician",                          "PN" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0100 ), "CodeValue",                                   "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0102 ), "CodingSchemeDesignator",                      "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0103 ), "CodingSchemeVersion",                         "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0104 ), "CodeMeaning",                                 "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x010b ), "CodeSetExtensionFlag",                        "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x010d ), "CodeSetExtensionCreatorUID",                  "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x0201 ), "TimezoneOffset",                              "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1010 ), "StationName",                                 "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1030 ), "StudyDescription",                            "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1032 ), "ProcedureCodeSequence",                       "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x103E ), "SeriesDescription",                           "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1040 ), "InstitutionalDepartmentName",                 "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1048 ), "PhysiciansOfRecord",                          "PN" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1050 ), "PerformingPhysician",                         "PN" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1060 ), "PhysicianReadingStudy",                       "PN" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1070 ), "OperatorName",                                "PN" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1080 ), "AdmittingDiagnosesDescription",               "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1090 ), "ModelName",                                   "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1110 ), "ReferencedStudySequence",                     "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1111 ), "ReferencedStudyComponentSequence",            "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1115 ), "ReferencedSeriesSequence",                    "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1140 ), "ReferencedImageSequence",                     "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1150 ), "ReferencedSOPClassUID",                       "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1155 ), "ReferencedSOPInstanceUID",                    "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1160 ), "ReferencedFrameNumber",                       "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x1199 ), "ReferencedSOPSequence",                       "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x2111 ), "DerivationDescription",                       "ST" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x2112 ), "SourceImageSequence",                         "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x2218 ), "AnatomicRegionSequence",                      "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x9007 ), "FrameType",                                   "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x9092 ), "ReferencedImageEvidenceSequence",             "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x9121 ), "ReferencedRawDataSequence",                   "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x9123 ), "CreatorVersionUID",                           "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x9205 ), "PixelPresentation",                           "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x9206 ), "VolumetricProperties",                        "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x9207 ), "VolumeBasedCalcTech",                         "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x9208 ), "ComplexImageComponent",                       "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0008, 0x9209 ), "AcquisitionContrast",                         "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x0000 ), "PatientGroupLength",                          "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x0010 ), "PatientName",                                 "PN" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x0020 ), "PatientId",                                   "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x0030 ), "PatientBirthdate",                            "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x0040 ), "PatientSex",                                  "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x1010 ), "PatientAge",                                  "AS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x1020 ), "PatientSize",                                 "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x1030 ), "PatientWeight",                               "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x1040 ), "PatientAddress",                              "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x2000 ), "MedicalAlerts",                               "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x2110 ), "ContrastAllergies",                           "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x2160 ), "EthnicGroup",                                 "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x2180 ), "Occupation",                                  "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x21b0 ), "AdditionalPatientHistory",                    "LT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x21c0 ), "PregnancyStatus",                             "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0010, 0x4000 ), "PatientComments",                             "LT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0000 ), "AcquisitionGroupLength",                      "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0010 ), "ContrastAgent",                               "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0015 ), "BodyPartExamined",                            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0020 ), "ScanningSequence",                            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0021 ), "SequenceVariant",                             "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0022 ), "ScanOptions",                                 "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0023 ), "MrAcquisitionType",                           "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0024 ), "SequenceName",                                "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0025 ), "AngioFlag",                                   "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0050 ), "SliceThickness",                              "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0070 ), "CountsAccumulated",                           "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0071 ), "AcquisitionTerminationCondition",             "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0080 ), "RepetitionTime",                              "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0081 ), "EchoTime",                                    "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0082 ), "InversionTime",                               "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0083 ), "NumberOfAverages",                            "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0084 ), "ImagingFrequency",                            "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0085 ), "ImagingNucleus",                              "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0086 ), "EchoNumber",                                  "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0087 ), "MagneticFieldStrength",                       "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0088 ), "SliceSpacing",                                "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0089 ), "PhaseEncodingSteps",                          "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0091 ), "EchoTrainLength",                             "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0093 ), "PercentSampling",                             "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0094 ), "PercentPhaseFov",                             "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0095 ), "PixelBandwidth",                              "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1000 ), "DeviceSerialNumber",                          "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1012 ), "SecondaryCaptureDate",                        "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1014 ), "SecondaryCaptureTime",                        "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1016 ), "SecondaryCaptureDeviceMan",                   "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1018 ), "SecondaryCaptureDeviceModel",                 "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1019 ), "SecondaryCaptureDeviceSoftwareVersion",       "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1020 ), "SoftwareVersion",                             "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1030 ), "ProtocolName",                                "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1050 ), "SpatialResolution",                           "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1060 ), "TriggerTime",                                 "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1063 ), "FrameType",                                   "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1081 ), "LowRRValue",                                  "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1082 ), "HighRRValue",                                 "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1083 ), "IntervalsAcquired",                           "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1084 ), "IntervalsRejected",                           "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1088 ), "HeartRate",                                   "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1090 ), "CardiacImages",                               "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1094 ), "TriggerWindow",                               "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1100 ), "ReconstructionDiameter",                      "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1149 ), "FovDimensions",                               "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1200 ), "LastCalibrationDate",                         "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1201 ), "LastCalibrationTime",                         "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1210 ), "ConvolutionKernel",                           "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1250 ), "ReceivingCoil",                               "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1251 ), "TransmittingCoil",                            "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1310 ), "AcquisitionMatrix",                           "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1312 ), "PhaseEncodingDirection",                      "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1314 ), "FlipAngle",                                   "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1315 ), "VariableFlipAngleFlag",                       "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1316 ), "SAR",                                         "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1318 ), "DB_DT",                                       "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x5100 ), "PatientPosition",                             "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9004 ), "ContentQualification",                        "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9005 ), "PulseSequenceName",                           "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9006 ), "MRImagingModifierSequence",                   "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9008 ), "EchoPulseSequence",                           "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9009 ), "InversionRecovery",                           "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9010 ), "FlowCompensation",                            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9011 ), "MultipleSpinEcho",                            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9012 ), "MultiplanarExcitation",                       "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9014 ), "PhaseContrast",                               "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9015 ), "TofContrast",                                 "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9016 ), "Spoiling",                                    "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9017 ), "SteadyStatePulseSequence",                    "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9018 ), "EchoPlanarPulseSequence",                     "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9019 ), "TagAngleFirstAxis",                           "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9020 ), "MagnetizationTransfer",                       "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9021 ), "T2Preparation",                               "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9022 ), "BloodSignalNulling",                          "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9024 ), "SaturationRecovery",                          "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9025 ), "SpectrallySelectedSuppression",               "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9026 ), "SpectrallySelectedExcitation",                "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9027 ), "SpatialPreSaturation",                        "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9028 ), "Tagging",                                     "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9029 ), "OversamplingPhase",                           "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9030 ), "TagSpacingFirstDimension",                    "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9032 ), "GeometryOfKspaceTraversal",                   "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9033 ), "SegmentedKspaceTraversal",                    "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9034 ), "RectilinearPhaseEncodeReordering",            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9035 ), "TagThickness",                                "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9036 ), "PartialFourierDirection",                     "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9037 ), "CardiacSynchronizationTechnique",             "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9041 ), "ReceiveCoilManufacturerName",                 "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9042 ), "MRReceiveCoilSequence",                       "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9043 ), "ReceiveCoilType",                             "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9044 ), "QuadratureReceiveCoil",                       "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9045 ), "MultiCoilDefinitionSequence",                 "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9047 ), "MultiCoilElementName",                        "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9048 ), "MultiCoilElementUsed",                        "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9049 ), "MRTransmitCoilSequence",                      "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9050 ), "TransmitCoilManufacturerName",                "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9051 ), "TransmitCoilType",                            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9053 ), "ChemicalShiftReference",                      "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9058 ), "MRAcquisitionFrequencyEncodingSteps",         "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9059 ), "Decoupling",                                  "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9060 ), "DecoupledNucleus",                            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9061 ), "DecouplingFrequency",                         "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9062 ), "DecouplingMethod",                            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9063 ), "DecouplingChemicalShiftReference",            "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9064 ), "KspaceFiltering",                             "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9069 ), "ParallelReductionFactorInPlane",              "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9073 ), "AcquisitionDuration",                         "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9074 ), "FrameAcquisitionDateTime",                    "DT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9075 ), "DiffusionDirectionality",                     "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9076 ), "DiffusionGradientDirectionSequence",          "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9077 ), "ParallelAcquisition",                         "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9078 ), "ParallelAcquisitionTechnique",                "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9080 ), "MetaboliteMapDescription",                    "ST" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9081 ), "PartialFourier",                              "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9082 ), "EffectiveEchoTime",                           "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9085 ), "CardiacSignalSource",                         "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9087 ), "DiffusionBValue",                             "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9089 ), "DiffusionGradientOrientation",                "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9090 ), "VelocityEncodingDirection",                   "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9091 ), "VelocityEncodingMinimumValue",                "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9093 ), "NumberOfKspaceTrajectories",                  "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9094 ), "CoverageOfKspace",                            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9098 ), "TransmitterFrequency",                        "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9100 ), "ResonantNucleus",                             "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9100 ), "RespiratoryMotionCompensationTechnique",      "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9101 ), "FrequencyCorrection",                         "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9104 ), "SlabThickness",                               "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9105 ), "SlabOrientation",                             "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9106 ), "MidSlabPosition",                             "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9107 ), "MRSpatialSaturationSequence",                 "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9112 ), "MRTimingAndRelatedParametersSequence",        "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9114 ), "MREchoSequence",                              "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9115 ), "MRModifierSequence",                          "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9117 ), "MrDiffusionSequence",                         "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9118 ), "CardiacTriggerSequence",                      "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9119 ), "MRAveragesSequence",                          "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9125 ), "MRFOVGeometrySequence",                       "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9147 ), "DiffusionAnisotropyType",                     "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9151 ), "FrameReferenceDatetime",                      "DT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9152 ), "MRMetaboliteMapSequence",                     "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9155 ), "ParallelReductionFactorOutOfPlane",           "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9168 ), "ParallelReductionFactorSecondInPlane",        "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9169 ), "CardiacBeatRejectionTechnique",               "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9170 ), "RespiratoryMotionCompensationTechnique",      "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9171 ), "RespiratorySignalSource",                     "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9172 ), "BulkMotionCompensationTechnique",             "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9174 ), "ApplicableSafetyStandardAgency",              "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9176 ), "OperatingModeSequence",                       "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9177 ), "OperatingModeType",                           "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9178 ), "OperationMode",                               "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9179 ), "SpecificAbsorptionRateDefinition",            "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9180 ), "GradientOutputType",                          "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9181 ), "SpecificAbsorptionRateValue",                 "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9182 ), "GradientOutput",                              "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9183 ), "FlowCompensationDirection",                   "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9199 ), "WaterReferencedPhaseCorrection",              "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9200 ), "MRSpectroscopyAcquisitionType",               "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9218 ), "TagSpacingSecondDimension",                   "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9219 ), "TagAngleSecondAxis",                          "SS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9220 ), "FrameAcquisitionDuration",                    "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9226 ), "MRImageFrameTypeSequence",                    "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9231 ), "PhaseEncodingStepsInPlane",                   "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9232 ), "PhaseEncodingStepsOutOfPlane",                "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9239 ), "SpecificAbsorptionRateSequence",              "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9240 ), "RFEchoTrainLength",                           "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x9241 ), "GradientEchoTrainLength",                     "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0000 ), "RelationshipGroupLength",                     "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x000D ), "StudyInstanceUid",                            "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x000E ), "SeriesInstanceUid",                           "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0010 ), "StudyId",                                     "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0011 ), "SeriesNumber",                                "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0012 ), "AcquisitionNumber",                           "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0013 ), "InstanceNumber",                              "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0020 ), "PatientOrientation",                          "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0030 ), "ImagePosition",                               "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0032 ), "ImagePositionPatient",                        "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0035 ), "ImageOrientation",                            "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0037 ), "ImageOrientationPatient",                     "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0050 ), "Location",                                    "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0052 ), "FrameOfReferenceUid",                         "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0060 ), "Laterality",                                  "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0070 ), "ImageGeometryType",                           "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0080 ), "MaskingImage",                                "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0100 ), "TemporalPositionId",                          "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0105 ), "NumberOfTemporalPositions",                   "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x0110 ), "TemporalResolution",                          "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x1001 ), "Acquisitions",                                "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x1002 ), "ImagesInAcquisition",                         "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x1040 ), "PositionReference",                           "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x1041 ), "SliceLocation",                               "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x4000 ), "ImageComments",                               "LT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9056 ), "StackID",                                     "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9057 ), "InStackPositionNumber",                       "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9071 ), "FrameAnatomySequence",                        "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9072 ), "FrameLaterality",                             "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9111 ), "FrameContentSequence",                        "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9113 ), "PlanePositionSequence",                       "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9116 ), "PlaneOrientationSequence",                    "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9128 ), "TemporalPositionIndex",                       "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9153 ), "TriggerDelayTime",                            "FD" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9156 ), "FrameAcquisitionNumber",                      "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9157 ), "DimensionIndexValues",                        "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9158 ), "FrameComments",                               "LT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9164 ), "DimensionOrganizationUID",                    "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9165 ), "DimensionIndexPointer",                       "AT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9167 ), "FunctionalGroupPointer",                      "AT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9213 ), "DimensionIndexPrivateCreator",                "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9221 ), "DimensionOrganizationSequence",               "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9222 ), "DimensionIndexSequence",                      "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0020, 0x9238 ), "FunctionalGroupPrivateCreator",               "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0000 ), "PresentationGroupLength",                     "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0002 ), "SamplesPerPixel",                             "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0004 ), "PhotometricInterpretation",                   "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0005 ), "ImageDimensions",                             "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0006 ), "PlanarConfiguration",                         "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0008 ), "NumberOfFrames",                              "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0009 ), "FrameIncrementPointer",                       "AT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0010 ), "ImageRows",                                   "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0011 ), "ImageColumns",                                "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0030 ), "PixelSpacing",                                "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0034 ), "PixelAspectRatio",                            "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0040 ), "ImageFormat",                                 "" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0100 ), "BitsAllocated",                               "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0101 ), "BitsStored",                                  "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0102 ), "HighBit",                                     "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0103 ), "PixelRepresentation",                         "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0106 ), "SmallestImagePixelValue",                     "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0107 ), "LargestImagePixelValue",                      "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0120 ), "PixelPaddingValue",                           "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0200 ), "ImageLocation",                               "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x0301 ), "BurnedInAnotation",                           "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x1050 ), "WindowCenter",                                "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x1051 ), "WindowWidth",                                 "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x1052 ), "RescaleIntercept",                            "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x1053 ), "RescaleSlope",                                "DS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x1054 ), "RescaleType",                                 "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x1055 ), "WindowCenterAndWidthExplanation",             "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x2110 ), "LossyImageCompression",                       "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x3003 ), "LUTExplanation",                              "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x9001 ), "DataPointRows",                               "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x9002 ), "DataPointColumns",                            "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x9110 ), "PixelMeasuresSequence",                       "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x9132 ), "FrameVOILUTSequence",                         "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0028, 0x9145 ), "PixelValueTransformationSequence",            "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0032, 0x0000 ), "StudyGroupLength",                            "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0032, 0x1032 ), "RequestingPhysician",                         "PN" ));
mAddEntry (DicomElement ( DicomTag ( 0x0032, 0x1033 ), "RequestingService",                           "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0032, 0x1070 ), "RequestedContrastAgent",                      "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0032, 0x1060 ), "RequestedProcedureDescription",               "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0032, 0x4000 ), "StudyComments",                               "LT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0038, 0x0050 ), "SpecialNeeds",                                "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0038, 0x0500 ), "PatientState",                                "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0000 ), "ProcedureStepGroupLength",                    "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0007 ), "ScheduledProcedureStepDescription",           "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0009 ), "ScheduledProcedureStepID",                    "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0241 ), "PerformedStationAETitle",                     "AE" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0242 ), "PerformedStationName",                        "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0243 ), "PerformedLocation",                           "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0244 ), "PerformedProcedureStepStartDate",             "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0245 ), "PerformedProcedureStepStartTime",             "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0250 ), "PerformedProcedureStepEndDate",               "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0251 ), "PerformedProcedureStepEndTime",               "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0252 ), "PerformedProcedureStepStatus",                "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0253 ), "PerformedProcedureStepId",                    "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0254 ), "PerformedProcedureStepDescription",           "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0255 ), "PerformedProcedureTypeDescription",           "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0260 ), "PerformedProtocolCodeSequence",               "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0275 ), "RequestAttributesSequence",                   "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0280 ), "CommentsOnThePerformedProcedureStep",         "ST" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0321 ), "FilmConsumptionSequence",                     "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x0555 ), "AcquisitionContextSequence",                  "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x1001 ), "RequestedProcedureID",                        "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x1002 ), "ReasonForTheRequestedProcedure",              "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x1003 ), "RequestedProcedurePriority",                  "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x1004 ), "PatientTransportArrangements",                "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x1005 ), "RequestedProcedureLocation",                  "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x1010 ), "NamesOfIntendedRecipientsOfResults",          "PN" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x1400 ), "RequestedProcedureComments",                  "LT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2001 ), "ReasonForTheImagingServiceRequest",           "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2004 ), "IssueDateOfImagingServiceRequest",            "DA" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2005 ), "IssueTimeOfImagingServiceRequest",            "TM" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2006 ), "PlacerOrderNumberImagingServiceRequest",      "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2007 ), "FillerOrderNumberImagingServiceRequest",      "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2008 ), "OrderEnteredBy",                              "PN" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2009 ), "OrderEnterersLocation",                       "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2010 ), "OrderCallbackPhoneNumber",                    "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2400 ), "ImagingServiceRequestComments",               "LT" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x9210 ), "LUTLabel",                                    "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0040, 0xa170 ), "PurposeOfReferenceCodeSequence",              "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0011 ), "NumberOfEnergyWindows",                       "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0012 ), "EnergyWindowInformationSequence",             "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0016 ), "RadiopharmaceuticalInformationSequence",      "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0020 ), "DetectorVector",                              "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0021 ), "NumberOfDetectors",                           "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0022 ), "DetectorInformationSequence",                 "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0050 ), "RotationVector",                              "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0051 ), "NumberOfRotations",                           "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0052 ), "RotationInformationSequence",                 "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0080 ), "SliceVector",                                 "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0081 ), "NumberOfSlices",                              "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0090 ), "AngularViewVector",                           "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0202 ), "TypeOfDetectorMotion",                        "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0400 ), "ImageID",                                     "SH" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0410 ), "PatientOrientationCodeSequence",              "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0414 ), "PatientGantryRelationshipCodeSequence",       "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0500 ), "SliceProgressionDirection",                   "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x1103 ), "ReconstructionMethod",                        "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x0088, 0x0140 ), "StorageMediaFilesetUid",                      "UI" ));
mAddEntry (DicomElement ( DicomTag ( 0x0088, 0x0200 ), "IconImageSequence",                           "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x2050, 0x0020 ), "PresentationLutShape",                        "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x5200, 0x9229 ), "SharedFunctionalGroupsSequence",              "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x5200, 0x9230 ), "PerFrameFunctionalGroupsSequence",            "SQ" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x0010 ), "OverlayRows",                                 "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x0011 ), "OverlayColumns",                              "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x0015 ), "FramesInOverlay",                             "IS" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x0022 ), "OverlayDescription",                          "LO" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x0040 ), "OverlayType",                                 "CS" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x0050 ), "OverlayOrigin",                               "SS" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x0051 ), "ImageFrameOrigin",                            "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x0100 ), "OverlayBitsAllocated",                        "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x0102 ), "OverlayBitPosition",                          "US" ));
mAddEntry (DicomElement ( DicomTag ( 0x6000, 0x3000 ), "OverlayData",                                 "OB" ));
mAddEntry (DicomElement ( DicomTag ( 0x7FE0, 0x0000 ), "PdGroupLength",                               "UL" ));
mAddEntry (DicomElement ( DicomTag ( 0x7FE0, 0x0010 ), "PixelData",                                   "" ));
mAddEntry (DicomElement ( DicomTag ( 0xFFFC, 0xFFFC ), "DataSetTrailingPadding",                      "OB" ));
mAddEntry (DicomElement ( DicomTag ( 0xFFFE, 0xE00D ), "ItemDelimiter",                               "" ));
mAddEntry (DicomElement ( DicomTag ( 0xFFFE, 0xE0DD ), "SqDelimiter",                                 "" ));
